package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````("$```````!``````````%"U````
M`````````$``.``(`$``&@`9``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````7`````````!<``````````0`````````!````
M!0```````````````````````````````````!R>````````')X`````````
M``$```````$````&````6*T```````!8K0$``````%BM`0``````,`4`````
M``#P!0```````````0```````@````8```!PK0```````'"M`0``````<*T!
M``````#@`0```````.`!````````"``````````$````!````!@"````````
M&`(````````8`@```````"P`````````+``````````$`````````%#E=&0$
M````^)0```````#XE````````/B4````````!`$````````$`0````````0`
M````````4N5T9`0```!8K0```````%BM`0``````6*T!``````"H`@``````
M`*@"`````````0`````````O=7-R+VQI8F5X96,O;&0N96QF7W-O```'````
M!`````$```!.971"4T0``,"OTC4$````!`````,```!085@```````````!A
M````:```````````````,0````X``````````````#@````/````0```````
M```P``````````,```!,````80`````````?````2P````8````=````%0``
M``````!"````5@```%T`````````%P```#P```!8``````````````!D````
M9@```"\````3````5P```$0````6````7````$4`````````2````"(````U
M````6P```"8````J``````````<```!.``````````P````L````9P```%H`
M``!*````(````$\```!E`````````%\`````````&````"X```!-````````
M````````````$@```#,`````````"@```&`````K``````````D`````````
M)````#D`````````4`````4```!&````&P```#L`````````````````````
M````20`````````Z````4P```&(`````````8P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````!0`````````````````````````````````````
M```````````````C````(0`````````I``````````L````G````*````"T`
M``````````````T`````````'````!H````9```````````````1````````
M`#0````R````-P```!X`````````````````````````!```````````````
M00```"4````````````````````````````````````_````0P````@`````
M```````````````^````4@``````````````50``````````````/0``````
M````````40````````!'````$`````````!4````60```#8```!>````````
M`````````````````````````````````````````````P`*`"`A````````
M`````````````````P`0`&BM`0````````````````"3````$@``````````
M```````````````,````$@`````````````````````````4````$@``````
M``````````````````!Q`P``$@`*`-@K````````"``````````<````(@``
M```````````````````````K````$@`````````````````````````8`P``
M$@`````````````````````````Q````$@````````````````````````!*
M`P``$``5`(BR`0`````````````````X````$@``````````````````````
M``""`P``$@`*`-@R````````*``````````_````$@``````````````````
M```````E`P``$@````````````````````````!'````$@``````````````
M``````````"=`P``$@`*`"@\````````:`````````"$````$@``````````
M``````````````!9`P``$``5`$BS`0````````````````!/````$@``````
M``````````````````"I`P``$``4`(BR`0````````````````!?````$@``
M``````````````````````!N````$@````````````````````````!U````
M$@````````````````````````!_````$@````````````````````````")
M````$@````````````````````````!8`P``$``5`$BS`0``````````````
M``"2````$@`````````````````````````4`@``$@``````````````````
M``````"8````$@````````````````````````"?````$@``````````````
M``````````"M````$@````````````````````````"^````$0``````````
M``````````````"B`@``(@````````````````````````#+````$@``````
M``````````````````"P`P``$@`*`"@N````````+`````````"]`P``$@`*
M`%@N````````>`````````#)`P``$@`*```T````````U`4```````#9````
M%@````````````````````````#L````$@`````````````````````````W
M`P``$@````````````````````````#W````$@``````````````````````
M`````0``$0`5`$"S`0``````"``````````(`0``$@``````````````````
M```````1`0``$@`````````````````````````.`P``$@``````````````
M```````````=`0``$@`````````````````````````D`0``$@``````````
M``````````````#6`P``$@`*`,A-````````'`$````````W`0``$0``````
M``````````````````!)`0``$@````````````````````````!9`0``$@``
M``````````````````````!G`0``$@````````````````````````!L`0``
M$@````````````````````````#A`P``$0`4`("R`0``````"`````````![
M`0``$@````````````````````````"'`0``$@``````````````````````
M``"<`0``$@````````````````````````"G`0``$@``````````````````
M``````!L`P``$``5`$BS`0````````````````#(`@``$@``````````````
M``````````"Z`0``$@`````````````````````````<!```$@`*`"`A````
M````"`````````#(`0``$@````````````````````````#0`0``$@``````
M``````````````````#<`0``$@````````````````````````!D`P``$``5
M`$BS`0````````````````#K`P``$@`*`-`N````````>`$```````#B`0``
M$@````````````````````````#M`0``$@````````````````````````#X
M`P``$@`*`.A.````````N`$```````#^`0``$@``````````````````````
M```"!```$``5`(BR`0`````````````````.!```$@`*`#@K````````0```
M```````6!```$@`*`%A1````````*`(````````%`@``$@``````````````
M``````````"*`@``(@`````````````````````````;!```$@`*`"`A````
M````"``````````,`@``$@`````````````````````````C!```$@`*`.`K
M````````1`(````````P!```$@`*```S````````_``````````3`@``$@``
M``````````````````````!"!```$@`*`$@P````````<``````````<`@``
M$@````````````````````````#7`@``$@`````````````````````````M
M`@``$@````````````````````````!0!```$@`*`+@P````````G```````
M```\`@``$@````````````````````````!%`@``$@``````````````````
M``````!+`@``$@`````````````````````````!`P``$@``````````````
M``````````!0`@``$@````````````````````````#T`@``$0`5`,BR`0``
M````"`````````!8`@``$@`````````````````````````L`P``$@``````
M``````````````````!?`@``$@````````````````````````!8!```$@`*
M`'!-````````5`````````!F`@``$0````````````````````````#I`@``
M$0`4``"R`0``````"`````````!A!```$@`*`-@Y````````3`(````````P
M`0``$@````````````````````````!K`@``$@``````````````````````
M```^`P``$@``````````````````````````;&EB<&5R;"YS;P!R96%L;&]C
M`&UE;6UO=F4`7U]C>&%?9FEN86QI>F4`<FUD:7(`<W1R<W1R`'-T<F-H<@!S
M=')N8VUP`'-T<G)C:'(`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?8V]N<W1R=6-T
M`'5N;&EN:P!?7VQS=&%T-3``<&5R;%]F<F5E`%]?<W1A=#4P`%]E>&ET`&UE
M;6-P>0!P97)L7V1E<W1R=6-T`%]?<W1A8VM?8VAK7V9A:6P`4$Q?9&]?=6YD
M=6UP`%!E<FQ?<W9?<V5T<'8`4$Q?8W5R<F5N=%]C;VYT97AT`'!E<FQ?86QL
M;V,`8VQO<V5D:7(`96YV:7)O;@!R96%D;&EN:P!?7V]P96YD:7(S,`!M96US
M970`4&5R;%]S869E<WES;6%L;&]C`%]?<W1A8VM?8VAK7V=U87)D`%!E<FQ?
M9W9?9F5T8VAP=@!?7W-P<FEN=&9?8VAK`')E860`4&5R;%]S>7-?:6YI=#,`
M4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]N97=84P!0
M97)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S>7-?=&5R;0!?7V5R<FYO`%!E<FQ?
M;6=?<V5T`&UK9&ER`'!E<FQ?<&%R<V4`4&5R;%]N97=84U]F;&%G<P!A8V-E
M<W,`9V5T<&ED`&UE;6-H<@!V9G!R:6YT9@!097)L7V%T9F]R:U]L;V-K`%!E
M<FQ?<W9?<V5T<'9N`'!E<FQ?<G5N`&QS965K`&]P96X`<W!R:6YT9@!G971U
M:60`<W1R;&5N`%]?<T8`<W1R8VUP`&QI8FTN<V\N,`!L:6)C<GEP="YS;RXQ
M`%]?9&5R96=I<W1E<E]F<F%M95]I;F9O`%]?<F5G:7-T97)?9G)A;65?:6YF
M;P!L:6)P=&AR96%D+G-O+C$`<'1H<F5A9%]A=&9O<FL`<W1R9'5P`&QI8F,N
M<V\N,3(`7U]P<F]G;F%M90!?7W!S7W-T<FEN9W,`7U]G971P=W5I9#4P`%]?
M<WES8V%L;`!?7W-T<&-P>5]C:&L`871E>&ET`%]L:6)C7VEN:70`<W1R=&]K
M`%]?<F5A9&1I<C,P`%]?8G-S7W-T87)T7U\`7U]B<W-?96YD7U\`7U]E;F1?
M7P!?96YD`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T
M<'=U:60`<&%R7V-L96%N=7``7V5D871A`'!A<E]B87-E;F%M90!P87)?9&ER
M;F%M90!P87)?;6MT;7!D:7(`<VAA7W5P9&%T90!M>5]P87)?<&P`<&%R7VEN
M:71?96YV`'-H85]F:6YA;`!?7V)S<U]S=&%R=`!X<U]I;FET`&UA:6X`7U]S
M=&%R=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C
M;&5A;@!P87)?9&EE`'-H85]I;FET`%A37TEN=&5R;F%L<U]005)?0D]/5``O
M=7-R+W!K9R]L:6(O<&5R;#4O-2XS."XP+V%A<F-H-C0M;F5T8G-D+71H<F5A
M9"UM=6QT:2]#3U)%.B]U<W(O<&MG+VQI8@``6*T!```````#!````````!A1
M````````8*T!```````#!````````*!0````````6*\!```````#!```````
M`&BM`0``````<*\!```````#!````````%BM`0``````D*\!```````#!```
M`````$"S`0``````H*\!```````#!````````&"M`0``````J*\!```````#
M!````````("R`0``````R*\!```````#!````````,BR`0``````V*\!````
M```#!`````````"R`0``````X*\!```````#!````````-@Y`````````+(!
M```````#!````````,"R`0``````"+(!```````#!`````````BR`0``````
M(+(!```````#!````````(!7````````*+(!```````#!````````+!3````
M````.+(!```````#!`````````!5````````0+(!```````#!````````&!7
M````````2+(!```````#!````````&A7````````4+(!```````#!```````
M`'!7````````6+(!```````#!````````'A7````````:+(!```````#!```
M`````$A7````````<+(!```````#!````````%!7````````@+(!```````#
M!````````(A7````````8*\!```````!!```!P``````````````:*\!````
M```!!```%```````````````>*\!```````!!```(0``````````````@*\!
M```````!!```(@``````````````B*\!```````&!```)P``````````````
MF*\!```````!!```,@``````````````L*\!```````!!```.P``````````
M````N*\!```````!!```30``````````````P*\!```````!!```5```````
M````````T*\!```````!!```8@```````````````+`!```````"!````P``
M````````````"+`!```````"!```!```````````````$+`!```````"!```
M!0``````````````&+`!```````"!```!P``````````````(+`!```````"
M!```"```````````````*+`!```````"!```"0``````````````,+`!````
M```"!```"@``````````````.+`!```````"!```#```````````````0+`!
M```````"!```#@``````````````2+`!```````"!```#P``````````````
M4+`!```````"!```$```````````````6+`!```````"!```$@``````````
M````8+`!```````"!```%@``````````````:+`!```````"!```%P``````
M````````<+`!```````"!```&```````````````>+`!```````"!```&0``
M````````````@+`!```````"!```&@``````````````B+`!```````"!```
M'```````````````D+`!```````"!```'0``````````````F+`!```````"
M!```'@``````````````H+`!```````"!```'P``````````````J+`!````
M```"!```(```````````````L+`!```````"!```(@``````````````N+`!
M```````"!```(P``````````````P+`!```````"!```*```````````````
MR+`!```````"!```*0``````````````T+`!```````"!```*@``````````
M````V+`!```````"!```+```````````````X+`!```````"!```+0``````
M````````Z+`!```````"!```+@``````````````\+`!```````"!```+P``
M````````````^+`!```````"!```,````````````````+$!```````"!```
M,P``````````````"+$!```````"!```-```````````````$+$!```````"
M!```-0``````````````&+$!```````"!```-@``````````````(+$!````
M```"!```.```````````````*+$!```````"!```.0``````````````,+$!
M```````"!```.@``````````````.+$!```````"!```/0``````````````
M0+$!```````"!```/@``````````````2+$!```````"!```0```````````
M````4+$!```````"!```00``````````````6+$!```````"!```0@``````
M````````8+$!```````"!```10``````````````:+$!```````"!```1@``
M````````````<+$!```````"!```2```````````````>+$!```````"!```
M3```````````````@+$!```````"!```30``````````````B+$!```````"
M!```3P``````````````D+$!```````"!```4@``````````````F+$!````
M```"!```50``````````````H+$!```````"!```5@``````````````J+$!
M```````"!```6```````````````L+$!```````"!```60``````````````
MN+$!```````"!```6@``````````````P+$!```````"!```6P``````````
M````R+$!```````"!```7```````````````T+$!```````"!```7@``````
M````````V+$!```````"!```7P``````````````X+$!```````"!```8```
M````````````Z+$!```````"!```90``````````````\+$!```````"!```
M9@``````````````^+$!```````"!```9P````````````````````````#P
M>[^IT```L!'^1_D0XC^1(`(?UA\@`]4?(`/5'R`#U=```-`1`D#Y$`(`D2`"
M'];0``#0$09`^1`B`)$@`A_6T```T!$*0/D00@"1(`(?UM```-`1#D#Y$&(`
MD2`"'];0``#0$1)`^1""`)$@`A_6T```T!$60/D0H@"1(`(?UM```-`1&D#Y
M$,(`D2`"'];0``#0$1Y`^1#B`)$@`A_6T```T!$B0/D0`@&1(`(?UM```-`1
M)D#Y$"(!D2`"'];0``#0$2I`^1!"`9$@`A_6T```T!$N0/D08@&1(`(?UM``
M`-`1,D#Y$((!D2`"'];0``#0$39`^1"B`9$@`A_6T```T!$Z0/D0P@&1(`(?
MUM```-`1/D#Y$.(!D2`"'];0``#0$4)`^1`"`I$@`A_6T```T!%&0/D0(@*1
M(`(?UM```-`12D#Y$$("D2`"'];0``#0$4Y`^1!B`I$@`A_6T```T!%20/D0
M@@*1(`(?UM```-`15D#Y$*("D2`"'];0``#0$5I`^1#"`I$@`A_6T```T!%>
M0/D0X@*1(`(?UM```-`18D#Y$`(#D2`"'];0``#0$69`^1`B`Y$@`A_6T```
MT!%J0/D00@.1(`(?UM```-`1;D#Y$&(#D2`"'];0``#0$7)`^1""`Y$@`A_6
MT```T!%V0/D0H@.1(`(?UM```-`1>D#Y$,(#D2`"'];0``#0$7Y`^1#B`Y$@
M`A_6T```T!&"0/D0`@21(`(?UM```-`1AD#Y$"($D2`"'];0``#0$8I`^1!"
M!)$@`A_6T```T!&.0/D08@21(`(?UM```-`1DD#Y$(($D2`"'];0``#0$99`
M^1"B!)$@`A_6T```T!&:0/D0P@21(`(?UM```-`1GD#Y$.($D2`"'];0``#0
M$:)`^1`"!9$@`A_6T```T!&F0/D0(@61(`(?UM```-`1JD#Y$$(%D2`"'];0
M``#0$:Y`^1!B!9$@`A_6T```T!&R0/D0@@61(`(?UM```-`1MD#Y$*(%D2`"
M'];0``"P$;I`^1#"!9$@`A_6T```L!&^0/D0X@61(`(?UM```+`1PD#Y$`(&
MD2`"'];0``"P$<9`^1`B!I$@`A_6T```L!'*0/D00@:1(`(?UM```+`1SD#Y
M$&(&D2`"'];0``"P$=)`^1""!I$@`A_6T```L!'60/D0H@:1(`(?UM```+`1
MVD#Y$,(&D2`"'];0``"P$=Y`^1#B!I$@`A_6T```L!'B0/D0`@>1(`(?UM``
M`+`1YD#Y$"('D2`"'];0``"P$>I`^1!"!Y$@`A_6T```L!'N0/D08@>1(`(?
MUM```+`1\D#Y$(('D2`"'];0``"P$?9`^1"B!Y$@`A_6T```L!'Z0/D0P@>1
M(`(?UM```+`1_D#Y$.('D2`"'];A`P*J&P``%,```)#!``"0(8`UD0"L1_D_
M``#K8@(`5/U[OJDA0`"1_0,`D?-3`:G3``"0%!P`D7.B-9&4`A/+E/)]DI0"
M`8M@@E_X<R(`D0``/]9_`A3K@?__5/-30:G]>\*HP`-?UL`#7]8?(`/5_7N]
MJ?T#`)&S4P&IM5L"J>$)`+3U`P&JU@``D,$``)##RD?YH@)`^2'D1_FE"D#Y
M1`!`^34``/EE``#YI`<`M,,``)!C[$?Y9```^4$`0/DB`$`YX@``-"$$`)%?
MO`!Q@?__5&$``/DB`$`Y8O__-4```+3K_O^7LO__E\```)#!``"0(6`UD0"X
M1_D_``#KH@$`5-,``)`4'`"1<X(UD2%``)&4`A/+E/)]DI0"`8M@@E_X<R(`
MD0``/]9_`A3K@?__5````)``H`21U?[_E\```)#!``"0(6`UD0#01_D_``#K
MH@$`5-,``)`4'`"1<X(UD2%``)&4`A/+E/)]DI0"`8M@@E_X<R(`D0``/]9_
M`A3K@?__5-;*1_FA`D#YH`I`N<("0/FH"P"4F?[_E\$``)#"``"P0@`+D2'L
M1_DB``#Y@/G_M<S__Q<"``#P0@`.D6,"@-)!`(!2@`"`T@#__Y<@`(!2SO[_
MEP````#]>[RI_0,`D?,+`/F`!P"TP@``D+@?`/E"R$?Y6`!`^3@'`+2U$P#Y
M%0"`4@(`0#E?]`!Q1!A`>D$#`%03`T#YDP4`M+;?`JFU?D"3M`\`^?<#`:KV
M`P"J]`,8JN`#$ZKB`Q6JX0,6JH[^_Y>````U8&IU.!_T`'%``@!4DXY`^//^
M_[6TUT&IMM]"J;@?0/G@`Q.J\PM`^?U[Q*C``U_6]0,`JJ(>0#A?]`!Q1!A`
M>J'__U2U`@!+X?__%Q\@`]64`AC+M08`D93^0Y/T`@"Y<P(5B^`#$ZJX'T#Y
MM-=!J;;?0JGS"T#Y_7O$J,`#7]:U$T#YN!]`^>;__Q<3`(#2Y/__%Q,`@-*X
M'T#YX?__%_U[O*G]`P"1]5L"J=8``)#S4P&ITP``D/4#`*K`SD?Y<\I'^;33
M`)$!`$#YH1\`^0$`@-+A`Q2JX`,5JJW__Y?@`0"THS>`N6("0/E`#`.+`01`
M^4%X(_CA_O^T`"``D0$$0/D!``#YH?__M>$#%*K@`Q6JG___EV#^_[76SD?Y
MH1]`^<`"0/D@``#*H```M?-30:GU6T*I_7O$J,`#7]9P_O^7'R`#U?U[L:G]
M`P"1\PL`^=,``)!ASD?Y(@!`^:)W`/D"`(#2P```M+0/`/GT`P"J`0!`.4$!
M`#6T#T#Y<\Y'^:%W0/E@`D#Y(```RH`)`+7S"T#Y_7O/J,`#7]:V%P#Y<_[_
ME_8#`*J@!@"TMV,#J1<``/`8``#PNB<`^??"#I$8XPZ1ND,!D;43`/G@`Q:J
M\_[_E\`%`+05-`"1X0,7JN`#%:KJ_O^7(/__-.$#&*K@`Q6JYO[_EZ#^_S2Y
M(P#YX`,4JMK^_Y?Y`P"JX`,5JM?^_Y<``!D+``@`$0!\0)/7_O^7XP,5JN(#
M%*KY`P"J`0``\"$`#Y'!_O^7X0,:JN`#&:H:_O^7'P0`,:```%2@6T"Y``P4
M$A\00'&@`@!4X`,9J@;^_Y?@`QFJ_/W_E[DC0/G6__\7'R`#U;0/0/FV%T#Y
MOO__%Q\@`]7@`Q:J+_[_E^`#%*K5_?^7M-=!J;;?0JFX'T#YNB=`^;3__Q?@
M`QFJI/__E^S__Q>TUP&IMM\"J;CG`ZFZ)P#Y#/[_EQ\@`]7]>[FI_0,`D?-3
M`:GS`P&J]5L"J=4``)#W8P.I]`,`JJ'.1_E@`D`Y(@!`^:(W`/D"`(#2'_0`
M<7,6DYK@`Q.JEO[_E_8#`*JADP&1X`,4JAK__Y?@!P"T]P,`JH_^_Y<?`!;K
MH@8`5+AG@+G7``"0&/-]TX`"0#D?]`!Q!!A`>H`,`%3A`Q2J(!Q`.!_T`'$$
M&$!ZH?__5"$`%,LA?$"3]\I'^<`*`)$```&+]@)`^7[^_Y?`:CCXH`L`M*-G
M@+F`!@"1X@)`^8$"0#D_]`!Q0GAC^"080'I!```YP```5`$40#A!'``X/_0`
M<2080'J!__]4000`D:`'@%)````Y8!9`."`4`#C`__\U``"`4K7.1_FB-T#Y
MH0)`^4$``<JA"`"U\U-!J?5;0JGW8T.I_7O'J,`#7]8``(#286I@..%J(#@`
M!`"1H?__-?#__Q?7``"0N6L$J;LK`/G@RD?Y&`!`^0`#0/F`!0"TX0,8J@``
M@%("```4X`,9*B*,0/@9!``1HO__M0`,`!$`?'V3P0``L"(@0[F"`@`U(@"`
M4B(@`[E!_O^7^P,`JL`#`+0Z?T"3X0,8JECS?=/B`QBJ3OW_E^#*1_D;``#Y
M6@<`D7][.OBY9P"YNRM`^;EK1*FE__\7'R`#U>$#`*K@`QBJ/OW_E_L#`*K@
MRD?Y&P``^3L!`+0Z?T"36/-]T_#__Q<!`(#2H___%P`"@-(9`(!2W/__%[EK
M1*F[*T#Y``"`$KC__Q>Y:P2INRL`^7O]_Y?]>[2I_0,`D?-3`:G3``"0]`,`
MJJ&#`)%BSD?Y0P!`^:-?`/D#`(#25/W_E^`!`#6A*T"Y`@"44B$,%!(_$$!Q
M)!!">F`!`%1SSD?YHE]`^6$"0/E!``'*@0$`M?-30:G]>\RHP`-?U@``@%+W
M__\700"`4N`#%*K`_?^7'P``<>`7GQKQ__\76/W_EQ\@`]7_0Q'1XG^`TOU[
M`*G]`P"1\PL`^=,``)#U6P*IM2,!D?=C`ZGV`P"J8\Y'^?<#`:H```#PX0,5
MJF0`0/FD)P+Y!`"`T@`@#Y%<_?^7'P``<8T%`%0#!`!1M`\`^>$#`*K```"0
M`,1'^1\@`]4?(`/50M`[U:3*8SA8:&#X)`,`-.,#`2IT?$"3X06`4N(#%*K@
M`Q6JH?W_EV`"`+3C`Q2JX@,5JN$#%JK@`QBJI_W_E[0/0/ESSD?YH2="^6`"
M0/D@``#*P`(`M?5;0JGW8T.I_7M`J?,+0/G_0Q&1P`-?UB/]_S6T#T#YX@,7
MJN$#%JK@`QBJ(?W_E^___Q<?(`/50=`[U<```)``Q$?Y'R`#U1\@`]4X:&#X
M]/__%[0/`/D._?^7'R`#U?_#$-'A`P"J`H"`TOU[`*G]`P"1\U,!J=0``)"S
MHP"1@\Y'^>`#$ZID`$#YI!<"^00`@-*__/^7```3RP`$`-%A`@"+/P`3ZXD!
M`%1@:F`X'[P`<<```%0(```4'R`#U2``0#D?O`!Q@0``5#_T'S@_`!/K8?__
M5.$%@%+@`Q.JP/S_ER`"`+0?`!/KJ`$`5.`#$ZI?_?^7E,Y'^:(70OF!`D#Y
M00`!RF$"`+7S4T&I_7M`J?_#$)'``U_6'R`#U1\``#GS__\7E,Y'^:$70OF`
M`D#Y(```RN```+7S4T&I````\/U[0*D`P`Z1_\,0D4C]_Q?/_/^7_7N_J430
M.]7"``"0P```D`#$1_D?(`/5'R`#U?T#`)%"M$?Y`P``\(!H8/@!``#P_7O!
MJ&-@#I$A@`^1`_W_%_U[OJE!T#O5P```D`#$1_D?(`/5'R`#U?T#`)'S"P#Y
M,P``BR!H8/CF__^7P@``D&`"0/GS"T#Y!```\$+P1_F$P!R1_7O"J`$``/`%
M`(!2XP,$JB$`$)$(_?\7'R`#U0``@-+``U_6_T,4T?U[`*G]`P"1]QL`^=<`
M`)#S4P&I]`,`JO43`/GS`P&JXLY'^:&S`9$```#P`&`0D4,`0/FCAP+Y`P"`
MTKC]_Y?U`P"JX06`4N`#%*I8_/^7(`(`M````/#A`Q2J`*`0D8'^_Y?@`Q2J
M]\Y'^:*'0OGA`D#Y00`!RL$-`+7S4T&I_7M`J?430/GW&T#Y_T,4D<`#7];@
M`Q.JN!\`^?3\_Y<8``#P`>,0D8G\_Y?S`P"JP`L`M+EK!*D:``#P&0``\+87
M`/E:PPZ1.0,1D;8C!)&[*P#Y8`)`.6`'`#2U``"TX0,3JN`#%:H-_?^7@`4`
M-.`#$ZH"_?^7^P,`J@`$`-%A`@"+?P(!Z\(!`%1@:F`X'[P`<:```%0*```4
M(@!`.5^\`'&!``!4/_0?.'\"`>MA__]4X`,3JO'\_Y?[`P"JX`,4JN[\_Y<`
M`!N+``0`D1_\#_'H`@!4`P``\.8#%*KE`QFJY`,3JF,@$9$"@(#2`0"`4N`#
M%JIU_/^7H<,!D>`#%JHN_/^7H```-:![0+D`#!02'R!`<6`"`%0!XQ"1``"`
MTDK\_Y?S`P"J0/G_M;CG0ZFZ[T2IMA=`^:;__Q<?(`/5U0(`M.$#&JK@`Q6J
MT_S_ET#^_S0[`(#2\P,:JMC__Q<A`(!2X`,6JHS\_Y=@_?\UX0,6J@```/``
MH!"1&?[_E^`#%JJ9_/^7MA=`^;CG0ZFZ[T2IE/__%_,#&JH[`(#2Q___%[@?
M0/F*__\7N.<#J;KO!*FV%P#Y%/S_EQ\@`]7]>[ZIX06`4OT#`)'S"P#Y\P,`
MJN'[_Y<?``#Q8`:`FO,+0/G]>\*H@/S_%Q\@`]7``@"T_7N^J?T#`)'S"P#Y
M\P,`J@(`0#E"`0`TF_S_EP`$`)$?`!#Q"`(`5.`#$ZKS"T#Y_7O"J.S^_Q<?
M(`/5\PM`^0```/#]>\*H`,`.D6K\_Q<?(`/5````\`#`#I%F_/\7'R`#U0``
M@-+S"T#Y_7O"J,`#7];]>[NI````\`!`$9']`P"1\U,!J=,``)#U6P*I%@``
M\&'.1_D4``#P]V,#J1<``/`8``#PE,(2D2(`0/FB)P#Y`@"`TK43`9$^_?^7
M````\`"`$9$[_?^7````\`"@$9$X_?^7````\`#@$9$U_?^7P`(2D3/]_Y<`
M``#P`$`2D3#]_Y?@8A"1+OW_EP"#$I$L_?^7X`,4JBK]_Y<```#P```3D2?]
M_Y<```#P`*`0D23]_Y<```#PX0,5J@!`$Y'<_/^7@```M.$#`*K@`Q2JJOW_
MEP```/#A`Q6J`*`3D=3\_Y>@``"T`@``\.$#`*I``!21H?W_EP```/#A`Q6J
M`$`4D<O\_Y=``@"TX0,`JN!B$)&9_?^7`0``\,`"$I$AX!21E?W_EW/.1_FA
M)T#Y8`)`^2```,K@`0"U\U-!J?5;0JGW8T.I_7O%J,`#7]8```#0X0,5J@"`
M%)&U_/^7P/W_M.$#`*H`@Q*1@_W_E^K__Q>+^_^7_7N]J0```-``@!*1_0,`
MD?,+`/FS``#PH9,`D6+.1_E#`$#YHQ<`^0,`@-*C_/^7X0,`J@``@%*A``"T
M(`!`.1_``'$$&$!ZX`>?&G/.1_FB%T#Y80)`^4$``<J!``"U\PM`^?U[PZC`
M`U_6;_O_E_U[KJFI``#PJ```\/T#`)&J@P21JX,#D2G-1_FJJP.IZ@:`$JLG
M`/FJ4P"YZ@^`$JI7`+D(Z4?YK+=#J:&+#JFJKT2IHY,/J:6;$*GA`P"JIX\`
M^:)#`)&@&X`]H1^`/:(C@#VC)X`]I"N`/:4O@#VF,X`]IS>`/2`!0/F@+P#Y
M``"`T@#!!)&L-P&IJB\"J;[[_Y?@'X!2]/K_EQ\@`]7_@P'1`0"`TO]#0-%"
M`(!2_7L`J?T#`)&D0T"1]A<`^;8``/#S4P&I]`,`*L/.1_EE`$#YA2P`^04`
M@-*[^_^7``0`T>$#`.L3/$"2(3Q`DF%&@=H3``'K!`@`5+=C`ZD8``#0%P``
MT+43`/FY(P#Y%0&`TA@#%9'W0A61N4,!D34`H/("`(!2X0,3JN`#%"JF^_^7
M'P0`L4`&`%3A`QFJX@,5JN`#%"I0^_^7`7Q`DQ\$`#$@!`!4/QP`\2D$`%0@
M(`#1(`,`BQ\`&>NC`P!4PP``D`0``!0`!`#1'P`9ZP,#`%1A"$'Y`@!`^5\`
M`>M!__]4<P(9R[430/FW8T.I```3B[DC0/G6SD?YH4-`D2(L0/G!`D#Y00`!
MRH$"`+7S4T&I_7M`J?870/G_@P&1_T-`D<`#7];@`Q>JB?__EW-"0-%_0D"Q
MX?G_5+=C0ZFU$T#YN2-`^0``@)+K__\7X`,8JG___Y?-__\7MV,#J;43`/FY
M(P#YZ/K_EQ\@`]7]>[^I_0,`D7C[_Y=O^_^7@```M```0/G]>\&HP`-?U@``
M@-+]__\7_7N[J?T#`)'S"P#YLP``\/5;`JD5``#0]QL`^;>"%9%BSD?Y]@,`
MJJ$3`9'@`Q>J0P!`^:,G`/D#`(#2\?O_EV`!`+2T#P#Y]`,`J@$`0#G!```T
MX0,6JHKZ_Y<@`@"TM`]`^04``!2T#T#YX0,6JJ""%9&U_/^7<\Y'^:$G0/E@
M`D#Y(```RF`#`+7U6T*I\PM`^?<;0/G]>\6HP`-?UN`#%JI/^_^7]0,`JN`#
M%*I,^_^7H`(`BP`(`)%-^_^7Y`,4JN(#%JH#``#08^`0D?4#`*H!``#0(2`1
MD37[_Y?A`Q6JX`,7JIC\_Y>T#T#YXO__%[0/`/F>^O^7'R`#U?U[IJG*``"0
M2D$(D?T#`)'S4P&IM```\/5;`JGU`P"J^2,`^;.3`9'W&P#Y&0``T(S.1_E`
MA4.IC0%`^:W/`/D-`(#21!5!J:"'"JE"C4*II)<&J4:=1*FBCPFI2*5%J::?
M"ZE+$4#YX0,3JDHU0/D@8Q"1J"<(J:L_`/FJ2P#YH/O_EX```+0!`$`Y]@,`
MJH$1`#6Z[P2IN!\`^8___Y?W`P"JH!$`M.`#%ZH-^_^7`/A_TP`$`)$.^_^7
MX@)`.?@#`*I"`0`T&@``T/8#&*I:XQ61X`,6JN$#&JKU^O^7U@H`D>(>0#AB
M__\UH$]`^<`)`+2Z8P*1-@"`T@4``!36!@"10`\6BP"`7_C@"`"TX0,3JGO[
M_Y?W`P"J(/__M`$`0#GA_O\TV/S_EZ#^_S3@`Q>JQ_K_E_8#`*I@!P"TX`,6
MJN?Z_Y?W`P"JX`,8JN3Z_Y<``!<+%Q`0$1H``-#W?D"3X`,7JN+Z_Y?E`QBJ
M0P,1D>(#%JH$``#0A``6D?L#`*H!``#0(2`6D<GZ_Y<!.(!2X`,;JH[Z_Y<?
M!``Q@`8`5*$C`Y'@`QNJ%?K_E_8#`"J@```UH--`N0`,%!(?$$!Q8`L`5*``
M`/"B`D#YXP,;J@$``-``Z$?Y(6`7D1<`@-(`P`21%OK_E[KO1*FX'T#YE,Y'
M^>`#%ZJBST#Y@0)`^4$``<H!'@"U\U-!J?5;0JGW&T#Y^2-`^?U[VJC``U_6
M'R`#U;JC`9$7`(!25MMW^+8!`+3``D`Y8`$`-.`#%JKW!@`1D/S_ER#__S3@
M`Q:J?_K_E_8#`*H@]_^U5MMW^+;^_[46`(#2M?__%U#Z_Y<``$"Y'T0`<4#Y
M_U2S`D#Y2_K_EZ4``/`$`$"YXP,;J@$``-"@Z$?YX@,3JB%@%I$7`(#2`,`$
MD>7Y_Y>Z[T2IN!]`^<___Q<?(`/5$/__E^`#%JIB^O^7]P,`JLG__Q<?(`/5
MN`,"D18`@%(`VW;X@`$`M.$#$ZK6!@`1!/O_EV#__[0!`$`Y(?__-%3Z_Y?W
M`P"J`.W_M0#;=OC`_O^UH`&`TG;Z_Y<7``#0^`,`JF(*@%+WPA619___%[CG
M0+EC^O^7'P,`:V'T_U2@TT"Y`"``$A\`!W'A\_]4X`,7JF?Z_Y?A`Q.J]P,`
MJ@```-``P!B1YOK_E^$#`*I`"@"TH`)`^1K]_Y?S`P"JP`D`M.`#$ZI6^O^7
M^`,`JA\,`''M`0!4`'Q`DP$``-``$`#1(>`8D6`"`(M5^O^7``$`-1\3`''`
M#@!4`!,`46#"((L`\%\X'[P`<2`.`%0>_O^7P```->`#$ZH!`(!2+/K_E_,#
M`"K`!@`U`0``T"'@%)$```#0`(`2D9/[_Y=3`Q&1`_K_EQ4``-`%``#0I<`<
MD>0#`"H!``#0XP,3JN(#&ZHAH!F1X`,7JO@#!:JUXAF1'_K_EQ```!0?(`/5
MW/G_EP``0+D?1`!Q`0(`5/#Y_Y?6!@`1Y`,`*N8#&*KE`Q8JXP,3JN(#&ZKA
M`Q6JX`,7J@_Z_Y<!.(!2X`,7JM3Y_Y<?!``QP/W_5.`#&ZI0^?^7X0,7JB!C
M$)%K^_^7X`,7JI?^_Y>X'T#YNN]$J5'__Q<?(`/5LP)`^;+__Q<F_O^7]0,`
MJB#Y_[<!*`#1`@"`4N`#$RKJ^?^7P@"`TJ&#!9'@`Q,JEOG_EQ\8`/&```!4
M````T``@&9'O_?^7````T`!@#I$"0`"1H6-!N0`00+D_``!KH?;_5*'+0GE`
M"$!Y/P``:R'V_U2AR@#1`@"`4N`#$RJUHP61T?G_EP(%@-+A`Q6JX`,3*GWY
M_Y<?H`#Q@```5````-``(!F1UOW_EP4``-`!``#0OT,&.:7`')'D`Q6J0P,1
MD>(#&ZHA8!F1X`,7JLKY_Y?`__\7M09`^?7Q_[3@`Q6JT?G_EQ\,`/%I\?]4
M`!``T0$``-"@`@"+(0`9D=+Y_Y<?``!Q<Q*5FH/__Q>Z[P2IN!\`^2CY_Y<?
M(`/5_7N[J:```/``Q$?Y'R`#U1\@`]4$``#0_0,`D?-3`:E3T#O5]5L"J;0`
M`/#W8P.IM1,!D8/.1_GA`Q6J8FI@^(``$I%D`$#YI"<`^00`@-)#P$(Y0\0"
M.33Z_Y>```"T`0!`.3_$`'%`"P!4(_W_EZ```/``Q$?Y'R`#U1\@`]5W`@"+
M8&I@^`$``-!C`(!2(@"`4B%`&I$L^?^7]@,`JF`!`+0!"$#Y`@``T.`"0/E"
M8!J1(0!`^0#Y_Y?`"D#Y`0!`^2`,0+G`"K`WH```\`#$1_D?(`/5'R`#U7@"
M`(M@:F#X`0``T&,`@%(B`(!2(8`:D=<``)`4^?^7]@,`JF`!`+0```#0X0,5
MJ@"@$)$&^O^7X@,`JD`'`+3!"D#Y``-`^2$`0/GD^/^7H```\`#$1_D?(`/5
M'R`#U79J8/AS`@"+(@"`4@$``-#@`Q:J(:`:D0WY_Y<"``#0X0,`JD(`&Y'@
M`Q:JU/C_EV("0/GS@@R1````T.$#%:H`8!"17\0".>GY_Y=@"@#YH`(`M`$X
M@%(9^?^7`00`$3\$`'$$B%%Z800`5)3.1_FA)T#Y@`)`^2```,J@`P"U\U-!
MJ?5;0JGW8T.I_7O%J,`#7]8`!$`YX/3_-*7__Q<?(`/58`9`^1'^_Y=@"@#Y
M(/W_M0```-``(!N1Z/C_EQ\@`]7@@@R1P@I`^0$$0/E``$#Y(0!`^4O[_Y?%
M__\7'R`#U>`"0/GQ^/^7J?__%YOX_Y?W@@R1`0``T.,#`"H@P!N1X8I`J2$`
M0/G4^/^7'R`#U?U[OJG]`P"1\U,!J?,#`*J(_/^7>_S_E_0#`*H!_?^7'P``
M<60:0/J!``!4\U-!J?U[PJC``U_68`)`.8#__S0!``#0@@"`TB$`%I'@`Q2J
M2OC_E\#^_S7@`Q.J\U-!J?U[PJ@+^O\7_X,*T:@``/`$X`"1">`!D?U[`*G]
M`P"1HF,`D0'-1_E'(`"1(P!`^:-/`?D#`(#2@0!`N8.$0/@A",!:X8`?^#\!
M!.MA_&#39?QHTR;<>-.E''B2(1P(4\8<<)(A``:JH^!#JB$``ZKA!`'X(?[_
M5$8`")%$`$#Y0B``D4,$0/E%'$#Y03!`^6,`!,I?``;K(0`%RB$``\HC_%_3
M800!JB%\0))!/`#Y8?[_5`400*F``&>>!AQ!J>$`9Y["`&>>@?Q"TR%X!*JC
M_%O30!QA+BQ\0)*!`6>>8Q0%JJN_0:DJ,X_22E"K\@D00/D-`&:>H`!GGFL!
M"HNB_$+3(!QB+D)X!:KO`0J+(0`"RJ-!(XNP%T#Y8P`+BTU\0))C``D+$`(*
MBPX`9IYK_%O3:Q4#JB$``XHA``S*L6-`^2$`!HO.`0>+(0`0B\X!#XMO_$+3
M:P$."^-Y`ZIN_5O30@`#RD(`"XK.%0NJS@$!"T$`#<JO"T.I</U"TQ!Z"ZHA
M``R+[P$*BVP`$,HA``^+8WQ`DLO]6].,`0Z*S_U"TVL5#JKO>0ZJC`$#RFL!
M`0M.``J+C`$-BPT"#\H!?D"2C`$.BV+]6].M`0N*;OU"TT(4"ZJM`0'*RWD+
MJD(`#`NM`0.+[`$+RN-]0)*P/T2I3OQ;T\X5`JJ,`0**$`(*BXP!`\JM`1"+
M[P$*B\X!#0N!`0&+4/Q"T\W]6],">@*J(0`/BZT5#JK/_4+3K0$!"VP!`LKA
M>0ZJ:WU`DK`_1:F,`0Z*C`$+RJ[]6],0`@J+@P$#BTP``<IC`!"+0GQ`DLX5
M#:J,`0V*S@$#"XP!`LJP_4+3`WH-JN\!"HN+`0N+S?U;TVL!#XNM%0ZJS_U"
MTZT!"PLL``/*ZWD.JK`_1JDA?$"2C`$.BJ[]6].,`0'*$`(*BX(!`HML``O*
M0@`0BV-\0)+.%0VJC`$-BLX!`@N,`0/*L/U"T^\!"HN!`0&+S/U;TP)Z#:HA
M``^+C!4.JL_]0M.,`0$+;0$"RN%Y#JIK?4"2L#]'J:T!#HJM`0O*COU;TQ`"
M"HNC`0.+30`!RF,`$(M"?$"2SA4,JJT!#(J0_4+3S@$#"PQZ#*JM`0+*[P$*
MBR,`#,JK`0N+S?U;TR%\0))K`0^+L$-`^:T5#JIC``Z*S_U"TZT!"POO>0ZJ
M8P`!R@X""HN+`0_*8P`"BZ+]6].,?4"28P`.B[!'0/E"%`VJ:P$-BJ[]0M-"
M``,+SGD-JFL!#,H-`@J+XP$.RFL!`8M!_%O3[WU`DFL!#8NP2T#Y(10"JF,`
M`HI-_$+3(0`+"ZUY`JIC``_*RP$-RF,`#(LB_%O3#`(*B\Y]0))C``R+0A0!
MJFL!`8JP3T#Y0@`#"VL!#LHL_$+3C'D!JA`""HMK`0^+0?Q;TVL!$(LA%`*J
M4/Q"TR$`"PNC`0S*"WH"JF,``HJ"`0O*KU-`^:U]0)*,?4"20@`!BF,`#<I"
M``S*8P`.BT(`#8ON`0J++_Q;T["W2JEC``Z+[Q4!JB[\0M/O`0,+SGD!JN/]
M6],!`@J+8Q0/JD(``8MA`0[*0D`CBVM]0)(A``^*0WQ`DB$`"\JJ`0J+(0`,
MB^W]0M-L_%O3(0`*BXP5`ZJJ>0^J+$`LBZU?0/G!`0K*D'U`DB$``DHB=)W2
M*P`+BR+;K?)O_$+3H0$"BPW^6]/C>0.J80$!BZT5$*I+`0/*+4`MBVL!#$JO
M?4"2:T$NB^S]6],N`@*+`?Y"TVL!#HLA>!"JC!4/JFQ!+(NP9T#Y:P`!RHY]
M0))M`0U*$`("BZI!*HOK_4+3S?U;TVMY#ZI*`1"+K14.JDU!+8NP:T#Y*@`+
MRJ]]0))*`0Q*$`("BTI!(XOL_5O3P_U"TTH!$(MC>`ZJC!4/JDQ!+(NP;T#Y
M:@$#RHY]0))*`0U*$`("BT%!(8O-_5O3ZOU"TR$`$(M*>0^JK14.JBU`+8NP
M<T#Y80`*RJ]]0)(L``Q*$`("BXM!*XO!_4+3[/U;TR%X#JIK`1"+C!4/JFQ!
M+(NP=T#Y2P$!RHY]0))M`0U*$`("BZ-!(XOK_4+3S?U;TVMY#ZIC`!"+K14.
MJK![0/EM0"V+(P`+RJ]]0))L``Q*$`("BXI!*HO#_4+3[/U;TV-X#JI*`1"+
MC!4/JDQ!+(NP?T#Y:@$#RHY]0))-`0U*$`("BZ%!(8OJ_4+3S?U;TTIY#ZHA
M`!"+K14.JBU`+8NP@T#Y80`*RJ]]0)(L``Q*$`("BXM!*XO!_4+3[/U;TR%X
M#JIK`1"+C!4/JFQ!+(NPAT#Y2P$!RHY]0))M`0U*$`("BZ-!(XOK_4+3S?U;
MTVMY#ZIC`!"+K14.JFU`+8NPBT#Y(P`+RJ]]0))L``Q*$`("BXI!*HO#_4+3
M[/U;TV-X#JI*`1"+C!4/JDQ!+(NPCT#Y:@$#RHY]0))-`0U*$`("BZ%!(8OJ
M_4+3S?U;TTIY#ZHA`!"+K14.JBU`+8MA``K*+``,2L']0M,A>`ZJKWU`DK`[
M4JF+02N+[/U;TQ`"`HN,%0^J:P$0BVM!+(M,`0'*<'U`DHT!#4JC02.+[/U"
MT\T!`HL._EO3C'D/JF,`#8O.%1"J;D`NBR,`#,IK``M*`_Y"TV-X$*K/?4"2
MK4-3J6I!*HNK`0*+[?U;TTH!"XNM%0^J34$MBXH!`\I.`0Y*ZOU"TTIY#ZH0
M`@*+P4$ABZM]0)(A`!"+<``*R@T"#4IN_5O3</U"T\X5"ZH+>@NJ+D`NBZ]#
M5*G!?4"2K$$LBRW\6]/O`0*+K14!JHP!#XM/`0O*C$$MB^X!#DJ-?4"2$`("
MB\-!(XNN_5O3SA4-JK']0M,O_$+38P`0B\,!`POA>0&J+GH-JG`!`<JO1U6I
M$`(,2LU]0)(L?$"2"D(JBR$`#JKB`0*+;_Q;TR$``XIP_$+30@$"B^H5`ZJ/
M`0V*0@$""P-Z`ZHA``^JBIN7TF]\0))JX['R*T`KBS$""HO!`0.J:P$1BR$`
M`HJQ`0^*4/Q;TR$`$:H0%@*JKD=6J5+\0M,+`@L+0GH"JE!\0)+.`0J+(0`,
MBV,``JIL_5O3<OU"TR$`#HN,%0NJ[@$0BF,`"XJ,`0$+8P`.JD%Z"ZIC``V+
M+GQ`DBT""HN+_5O30@`!JF,`#8N2_4+3#0(.BK&[0/EK%0RJ0@`,BFL!`PM"
M``VJ0WH,JD(`#XMM?$"2+P(*BVS]6],A``.J<OU"TT(`#XNQOT#YSP$-BHP5
M"ZHA``N*C`$""R$`#ZI">@NJ(0`0BT]\0)(P`@J+B_U;TV,``JJ2_4+3(0`0
MB['#0/FP`0^*:Q4,JF,`#(IK`0$+8P`0JD%Z#*IC``Z+,'Q`DBX""HML_5O3
M0@`!JG+]0M-C``Z+L<=`^>X!$(J,%0NJ0@`+BHP!`PM"``ZJ0WH+JD(`#8MN
M?$"2+0(*BXO]6],A``.JDOU"TT(`#8NQRT#Y#0(.BFL5#*HA``R*:P$""R$`
M#:I">@RJ(0`/BTU\0)(O`@J+;/U;TV,``JIR_4+3(0`/B['/0/G/`0V*C!4+
MJF,`"XJ,`0$+8P`/JD%Z"ZIC`!"++WQ`DC`""HN+_5O30@`!JI+]0M-C`!"+
ML=-`^;`!#XIK%0RJ0@`,BFL!`PM"`!"J0WH,JD(`#HMP?$"2+@(*BVS]6],A
M``.J<OU"TT(`#HNQUT#Y[@$0BHP5"ZHA``N*C`$""R$`#JI">@NJ(0`-BTY\
M0)(M`@J+B_U;TV,``JJ2_4+3(0`-B[';0/D-`@Z*:Q4,JF,`#(IK`0$+8P`-
MJD%Z#*IC``^++7Q`DB\""HML_5O30@`!JG+]0M-C``^+L=]`^<\!#8J,%0NJ
M0@`+BHP!`PM"``^J0WH+JD(`$(MO?$"2,`(*BXO]6],A``.JDOU"TT(`$(NQ
MXT#YL`$/BFL5#*HA``R*:P$""R$`$*I">@RJ(0`.BU!\0)(N`@J+;/U;TV,`
M`JIR_4+3(0`.B['G0/GN`1"*C!4+JF,`"XJ,`0$+8P`.JD%Z"ZIC``V++GQ`
MDBT""HN+_5O30@`!JI+]0M-C``V+L>M`^0T"#HIK%0RJ0@`,BFL!`PM"``VJ
M0WH,JD(`#XMM?$"2+P(*BVS]6],A``.J0@`/B['O0/G/`0V*C!4+JB$`"XJ,
M`0(+<OU"TR$`#ZI">@NJ(0`0BXO]6],P`@J+(0`0BVL5#*IK`0$+3WQ`DK$'
M7JEC``*JL`$/BF,`#(J2_4+38P`0JDQZ#*HQ`@J+D'U`DD(`#*IC``Z+;OU;
MT\X5"ZI"``N*8P`1B_$!$(K#`0,+0@`1JF[]0M,A``J+RWD+JD(`#8MM_%O3
M;GU`DD(``8NM%0.J@0$+JE)`+8NL^T#Y`@(.BB$``XI-?D"2(0`"JF+\0M-#
M>`.JB@$*BR$`#XNL_5O38@$#RB$`"HN,%0VJK_U"TRQ`+(M!`!)*(0`0BY%]
M0)*JPU^IPCJ8TD),N?(K_EO32@$"BVL5$:HA``J+ZGD-JBM`*XMA``K*;WU`
MDB$`#$KM_5O3#`("BR$`#HLN_D+3SGD1JB$`#(NM%0^J3`$.RBU`+8NA!T'Y
ML'U`DHL!"THA``*+#/Y;TVM!(XOC_4+3:P$!BXP5$*IA>`^J;$$LBZ,+0?G+
M`0'*CWU`DFL!#4IC``*+[?U;TVI!*HL+_D+3:WD0JDH!`XNM%0^J(P`+RDU!
M+8NJ#T'YL'U`DF,`#$I*`0*+#/Y;TV-`+HON_4+38P`*BXP5$*K*>0^J;$`L
MBVX!"LJC$T'YCWU`DLX!#4IC``*+[?U;T\%!(8L._D+3(0`#BZT5#ZK#>1"J
M+4`MBU`!`\JA%T'YKGU`DA`"#$HA``*+S/U;TPM"*XOP_4+3:P$!BXP5#JH!
M>@^J;$$LBW```<JK&T'YCWU`DA`"#4IK`0*+[?U;TPI"*HO0_4+32@$+BZT5
M#ZH+>@ZJ34$MBS``"\JJ'T'YKGU`DA`"#$I*`0*+S/U;TP-"(XOP_4+38P`*
MBXP5#JH*>@^J;$`LBW`!"LJC(T'YCWU`DA`"#4IC``*+[?U;TP%"(8O0_4+3
M(0`#BZT5#ZH#>@ZJ+4`MBU`!`\JA)T'YKGU`DA`"#$HA``*+S/U;TPM"*XOP
M_4+3:P$!BXP5#JH!>@^J;$$LBW```<JK*T'YCWU`DA`"#4IK`0*+[?U;TPI"
M*HO0_4+32@$+BZT5#ZH+>@ZJ34$MBS``"\JJ+T'YKGU`DA`"#$I*`0*+S/U;
MTP-"(XOP_4+38P`*BXP5#JH*>@^J;$`LBW`!"LJC,T'YCWU`DA`"#4IC``*+
M[?U;TP%"(8O0_4+3(0`#BZT5#ZH#>@ZJ+4`MBU`!`\JA-T'YKGU`DA`"#$HA
M``*+S/U;TPM"*XOP_4+3:P$!BXP5#JH!>@^J;$$LBW```<JK.T'YCWU`DA`"
M#4IK`0*+[?U;TPI"*HO0_4+32@$+BZT5#ZH+>@ZJ34$MBS``"\JJ/T'YKGU`
MDA`"#$I*`0*+S/U;TP-"(XOP_4+38P`*BXP5#JH*>@^J;$`LBZ]#0?EC`0K*
MD'U`DFT`#4JA02&+`_Y;T^T!`HO/_4+38Q00JB$`#8OM>0ZJ(4`CBZ]'0?E#
M`0W*+GQ`DF,`#$H,_D+3[P$"BXQY$*IK0"N+P_U;TVL!#XMC%`ZJL`$,RJ]+
M0?EC``L+`0(!2LO]0M,J0"J+X0$"BV+\6]-*`0&+0A0#JF%Y#JI"``H+)@`&
M"PC-1_F'`0<+J0$)"T4`!0N#``,+!AP!J04,`*D)$`#YH4]!^0`!0/D@``#*
M@```M?U[0*G_@PJ1P`-?UD+T_Y<?(`/5_7N_J0`0@-+]`P"1W?3_EQ\8`/DF
M8(32)7&5TL2?F]+#CHK2`CZ<TJ;HK/*E^;WR1!>S\D,&HO)">KCR!A0`J00,
M`:D"?`*I'W@`N?U[P:C``U_6'R`#U?U[O*E"?$"3_0,`D?-3`:D4X`"1]5L"
MJ?4#`*KW8P.I]@,"JO,#`:H%C$*I`'A`N:0,`@N_``3K8Y2#FF)T0HNDB@*I
MX`(`-!<(@%+W`@!+WP(7:X#"((O7TI<:^'Y`D^(#&*H)]/^7H'I`N>`"``N@
M>@"Y'P`!<<```%3S4T&I]5M"J?=C0ZG]>\2HP`-?UM8"%TMS`AB+X`,5JHO[
M_Y??_@!QC0(`5-8"`5'8?@93%V<:4_<"`9%W`A>+8@Y`J7,"`9&"#@"IX`,5
MJF(.?:F"#@&I8@Y^J8(.`JEB#G^I@@X#J7G[_Y=_`A?K@?[_5-8:&$O"?D"3
MX0,3JN`#%*KB\_^7MGH`N?-30:GU6T*I]V-#J?U[Q*C``U_6'R`#U?U[O*GC
M#X`2_0,`D?-3`:GS`P&J]QL`^3?@`)'U6P*I]`,`JC780JFA(@-3(@0`$>#"
M(HM?X`!QX\HA."T+`%0!"(!2(@`"2T)\0),!`(!2\O/_E^`#$ZI4^_^7?_X#
MJ7_^!*E__@6I?S8`^<#^4-/!_EC38,8!.<#^2--AP@$YH?Y8TV#*`3F@_E#3
M=LX!.6'2`3E@U@$YH/Y(TW7>`3E@V@$YX`,3JD#[_Y=A`D#YX`,3JB'\6-.!
M`@`Y80)`^2'\4-.!!@`Y80)`^2'\2-.!"@`Y80)`^8$.`#EA!D#Y(?Q8TX$2
M`#EA!D#Y(?Q0TX$6`#EA!D#Y(?Q(TX$:`#EA!D#Y@1X`.6$*0/DA_%C3@2(`
M.6$*0/DA_%#3@28`.6$*0/DA_$C3@2H`.6$*0/F!+@`Y80Y`^2'\6-.!,@`Y
M80Y`^2'\4-.!-@`Y80Y`^2'\2-.!.@`Y80Y`^8$^`#EA$D#Y(?Q8TX%"`#EA
M$D#Y(?Q0TX%&`#EA$D#Y(?Q(TX%*`#EA$D#Y@4X`.?-30:GU6T*I]QM`^?U[
MQ*A3\_\7`0>`4B(``DM"?$"3`0"`4IKS_Y>N__\7H```T`!`"Y$!($$Y00,`
M-:$``+`B`(!2`B`!.2"P1_F@`0"T_7N_J:```-#]`P"1``1!^1_S_Y>@``"P
M`-Q'^6`!`+3]>\&H(```D`"@&9',\_\7H```L`#<1_G```"T(```D`"@&9'&
M\_\7_7O!J,`#7];``U_6H```T`%`"Y$"0$LY8@$`-:(``+`C`(!2`T`+.4#`
M1_G```"T(```D"$@`)$`H!F13O/_%Q\@`]7``U_6`````/U[N:G]`P"1\U,!
MJ;0``+"#SD?YHH<$J:(C`9%D`$#YI#<`^00`@-*@7P"YH4,!D:!S`9%Q\_^7
MH```L*(``+``X$?Y0MA'^>$#`JI[\_^7H```L`"\1_D``$`YX`D`-$'0.]6U
M6P*ILP``T+<;`/F@``"P`,1'^1\@`]4?(`/5(VA@^*)?0+E`$``150P`$6$(
M4CD`?'V3(00`,F$($CE&\_^7I@``L*0K0/EG@@R1`P``D,;41_ECX!R1`0``
MD*5?0+F"`$#Y(0`=D0(,`*F_!`!QP@!`^0$,`/D""`#YX`0`^8T)`%2$(`"1
MI0P`$8$`@%*#A$#X`]@A^"$$`!$_``5K@?__5"1\?9-V@@R1'V@D^.,#`*KA
M__^P!`"`TN(#%2K`#D#Y(>`MD5?S_Y?`!0`T=8(,D;:3`9&@#D#Y\O+_E_<#
M`"KA`Q:J````D`!`$I$5]/^7``0`M'."#)%@#D#YU?+_ESCS_Y>4SD?YX`,7
M*J(W0/F!`D#Y00`!RN$$`+6U6T*I\U-!J;<;0/G]>\>HP`-?UNSR_Y>S``#0
M8H(,D4`,`/FU6P*IMQL`^8`#`+2U\O^70=`[U:```+``Q$?Y'R`#U1\@`]4@
M:&#X'Q@D.:?__Q>@"D#YP```M#SZ_Y?>__\7P`Y`^4OS_Y?1__\7````D.$#
M%JH`8!"1ZO/_EZ`*`/F@^O^T,?K_E]/__Q<$!(#2O?__%[_R_Y<@`(!2:?+_
MEW!S7W-T<FEN9W,@;6ES<VEN9PH``````'!E<FQX<VDN8P``````````0T%#
M2$4``"X`````````+BX````````E<R\E<P```"]P<F]C+V-U<G!R;V,O97AE
M`````````$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@``````26YT97)N
M86QS.CI005(Z.D)/3U0`````4$%27U1%35```````````%!!4E]04D]'3D%-
M10`````Z`````````"\`````````)7,E<R5S``!015),-4Q)0@``````````
M4$523$Q)0@!015),-4]05```````````4$523$E/``!005)?24Y)5$E!3$E:
M140`4$%27U-005=.140``````%!!4E]#3$5!3@````````!005)?1$5"54<`
M````````4$%27T-!0TA%`````````%!!4E]'3$]"04Q?1$5"54<`````````
M`%!!4E]'3$]"04Q?5$U01$E2`````````%!!4E]435!$25(```````!005)?
M1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``````````,0````````!L
M<V5E:R!F86EL960`````<F5A9"!F86EL960``````$Q$7TQ)0E)!4EE?4$%4
M2`!365-414T``"4P,G@`````<&%R+0`````E<R5S)7,E<P``````````)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H
M97)R;F\])6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I
M<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E
M<F%T:6]N*0H```````!0051(`````'!A<FP`````+G!A<@````!S:&]R="!R
M96%D````````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S
M=&5M<"TE=2TE=25S```````````8`````````'!E<FP`````,`````````!0
M05(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`U.0```%5N86)L92!T;R!C<F5A
M=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M```````````M90```````"TM````````55-%4@````!54T523D%-10``````
M````5$U01$E2``!414U01$E2`%1%35``````5$U0```````O=&UP+P```&5V
M86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P
M.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A
M<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C
M:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M
M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A
M8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P
M-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@
M)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@
M+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H
M=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@
M)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O
M<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"10
M05)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'
M24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU
M;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N
M86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[
M4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;
M4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ
M9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P
M87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F
M)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M
M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)
M3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R
M:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N
M90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@
M)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^
M)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]
M"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE
M9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV
M*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H
M"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I
M+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I
M;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>
M35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D[
M"F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R
M7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?
M5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T
M:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT[
M"G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S
M*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O
M;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@
M34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I
M.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA
M9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI
M.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I
M=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)
M3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?
M1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#
M04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@
M;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M
M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O
M9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO
M=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D
M;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@[
M"FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@
M("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H
M:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@
M/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN
M72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO
M?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B
M=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E
M9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I
M*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@
M/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA
M;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(
M+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D
M;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U
M;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@
M=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*
M)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H
M)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@
M>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG
M="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M
M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N
M("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O
M+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D
M9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F
M:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO
M9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@
M/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.
M0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H
M)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64[
M"GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S
M:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T
M<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@
M(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT
M96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]
M"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A
M8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI
M=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D
M<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@
M<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*
M:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A
M<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q
M("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%
M?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V
M:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=
M(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D
M,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q
M(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I
M('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I
M('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]
M("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL
M)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@
M*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q
M6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E
M<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF
M("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%2
M7U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z
M.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#
M+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ
M1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI3
M2$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E
M9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D
M:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H
M)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH
M("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II
M<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H
M)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG
M*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N
M*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII
M9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R
M(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM
M>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N
M;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC
M;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&
M:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL
M93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R
M(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB
M:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F
M:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A
M9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D
M+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]6
M15)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A
M9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B
M.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U
M:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG
M<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[
M<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C
M:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D
M97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E
M>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@
M;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K
M97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF
M("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME
M>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92![
M"F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D
M:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*
M;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@
M>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D
M;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I
M('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*
M?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I
M='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@
M/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN
M9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT
M96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D
M=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B
M/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD
M("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M
M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA
M;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T
M:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET
M=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E
M5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF
M("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*
M?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@
M/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^
M861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D
M8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE
M7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<
M,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D[
M"B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F
M9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN
M="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E
M(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D
M(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D
M969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!0
M05(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E
M($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]
M($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C
M($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^
M9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F
M86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(
M*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E
M("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@
M*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP
M+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD
M(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D
M>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y
M.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U
M;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R
M86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A
M=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@
M)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I
M>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E
M(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@
M>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T
M7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;
M17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET[
M"F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*
M?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I
M92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@
M72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A
M;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'
M5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A
M=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O
M<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER
M92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T
M.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R
M<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@
M1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)
M3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S
M.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z
M.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T
M<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E
M(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L
M('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E
M<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I
M<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R
M97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P
M871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%
M35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW
M("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I
M9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN
M960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z
M.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N
M86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).
M04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER
M(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R
M;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII
M9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"([
M"GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D
M;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K
M("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H
M*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG
M=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@
M)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H
M(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D
M8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H
M95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D
M8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%2
M7T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H
M95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@
M/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?
M<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*
M;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@
M)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM
M>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I
M;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T
M96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D
M9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L
M;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK
M*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@
M*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%2
M7U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L
M(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H
M(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N
M86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D
M<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N
M.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P
M?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]4
M14U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1
M)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER
M)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE
M(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@
M(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O
M9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345]
M.PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD
M<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W
M9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@
M*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z
M(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN
M/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@
M>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R
M;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@
M*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@
M*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6
M>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?
M)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%2
M7T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@
M*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN
M="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*
M<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[
M)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I
M=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K
M86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF
M:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP
M;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C
M:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID
M;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]
M("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ
M7U]%4E)/4CL*,3L*7U]%3D1?7PH``1L#.P0!```?````,(S__QP!``"8C/__
M1`$```B.__^X`0``&(___S`"``#`C___9`(``%"1___X`@``D)/__UP#```@
ME/__B`,``$B5___P`P``0);__RP$``"`EO__4`0``."6__]X!```Z);__XP$
M```PF?__#`4``&"9__\T!0``V)G__W0%``!0F___L`4``,";___8!0``8)S_
M__0%``#@G?__E`8```B>__^X!@``")___PP'``#@I/__D`<``#"G___,!P``
MF*?__U`(``!XN/__>`@``-"X__^<"```\+G__^0(``"HN___A`$``""\__]P
M`0``8+S__P`(````````$``````````!>E(`!'@>`1L,'P`D````&`````R+
M__]D`````$<.()T$G@-"#1U!DP*4`4W>W=/4#!\`*````$````!,B___;`$`
M``!!#C"=!IX%00T=090#DP1!E@&5`@`````````0````;````*BZ__\\````
M`````#````"`````'+K__W@`````2@X0G0*>`4(-'4;>W0P?`$D,'1"=`IX!
M0=[=#!\```````!T````M````$B,__\0`0```$$.0)T(G@=!#1U!DP9#F`%$
ME01(EP*6`T*4!4[5U$'7UD'80][=TPP?`$$,'4"3!I4$F`&=")X'2)0%E@.7
M`D?80=740=?60M[=TPP?`$$,'4"3!I4$F`&=")X'0=5!V$.8`4+8```P````
M+`$``.",__^D`````$$.0)T(G@=!#1U!E026`T*3!I0%8@K>W=76T]0,'P!!
M"P``D````&`!``!4C?__C`$```!!#O`!G1Z>'4$-'4&3'$>4&T341][=TPP?
M`$$,'?`!DQR4&YT>GAU!EAE$F!>7&$.:%425&DV9%EW90M77V-I!U$'60I0;
ME1J6&9<8F!>:%475U$'7UD'80=I!E!N5&I89EQB8%YD6FA5#U-76U]C9VD&5
M&I0;09<8EAE!F1:8%T&:%6````#T`0``4([__T`"````00YPG0Z>#4$-'4&3
M#)0+0I4*E@E+EPB8!WT*WMW7V-76T]0,'P!!"TB:!9D&09L$8`K;0=K90@M*
MV=K;0ID&F@6;!$3:V4';0YH%F09!FP0````H````6`(``"R0__^,`````$$.
MP`&=&)X700T=09,6E!56"M[=T]0,'P!!"V0```"$`@``D)#__R0!````00[0
M"$*=B@&>B0%!#1U!DX@!0I6&`9:%`427A`&8@P%,E(<!5M1*W=[7V-76TPP?
M`$$,'=`(DX@!E(<!E88!EH4!EX0!F(,!G8H!GHD!0M1.E(<!````.````.P"
M``!0D?__^`````!!#K`(0YV&`9Z%`4$-'4&3A`&4@P%H"MW>T]0,'P!""TP*
MW=[3U`P?`$$+(````"@#```,DO__0`````!!#A"=`IX!1PT=1=[=#!\`````
M)````$P#```HDO__7`````!!#B"=!)X#1@T=09,"2M[=TPP?`````!````!T
M`P``8)+__P@`````````?````(@#``!4DO__1`(```!!#I`*09VB`9ZA`4$-
M'4&7G`%"DZ`!E)\!2I6>`54*W=[7U=/4#!\`00M"F)L!1YJ9`9F:`4.6G0%$
MFY@!>`K9V$';VD'60@M3"M9!V=A!V]I!"T/6V=K;0=A"F9H!F)L!09N8`9J9
M`4&6G0$````D````"`0``!R4__\L`````$$.()T$G@-"#1U!DP)&WMW3#!\`
M````/````#`$```DE/__>`````!"#B"=!)X#00T=09,"2@K>W=,,'P!""T/>
MW=,,'P!'#!T@DP*=!)X#0][=TPP?`#@```!P!```7)3__W@!````00Y0G0J>
M"4,-'4&3")0'0I4&E@5$EP28`P)("M[=U]C5UM/4#!\`00L``"0```"L!```
MF)7__W``````00XPG0:>!4,-'4&3!%4*WMW3#!\`00L8````U`0``."5__^<
M`````$$.H`*=))XC0PT=G````/`$``!DEO__?`$```!!#F!"#N"`!$*=C$">
MBT!!#1U"EH=`0I.*0)2)0$Z8A4"7AD!#E8A`09F$0&/50=C70ME)W=[6T]0-
M'T$.@(`$00X`00P=X(`$DXI`E(E`E8A`EH=`EX9`F(5`F81`G8Q`GHM`1MC7
M0=5!V4*5B$"7AD"8A4"9A$!#U=?8V4&8A4"7AD!!E8A`09F$0````"````"0
M!0``1)?__R@`````00X0G0*>`4$-'44*WMT,'P!!"U````"T!0``2)?___P`
M````00Y0G0J>"4$-'4&3"$*5!I8%0I<$2Y0'1]1!E`=!U$S>W=?5UM,,'P!!
M#!U0DPB4!Y4&E@67!)T*G@E4U$*4!P```(`````(!@``])?__]0%````00Z@
M`YTTGC-##1U!DS*4,4*5,)8O1)DLERY;FRJ:*T&8+0)5V]I!V$O>W=G7U=;3
MU`P?`$(,':`#DS*4,94PEB^7+I@MF2R:*YLJG32>,V/;VD'82)@MFBN;*@)U
M"MA!V]I""P)$V-K;09LJFBM!F"T``#@```",!@``2)W__TP"````00Y0G0J>
M"48-'4&3")0'1)4&E@67!)@#`F<*WMW7V-76T]0,'P!!"P```#````#(!@``
M7)___V@`````00X@G02>`T$-'4&3`I0!2@K>W=/4#!\`00M+WMW3U`P?``!,
M````_`8``%BT__\H`@```$$.<)T.G@U!#1U!DPR4"U>6"94*0I<(`D;6U4+7
M0=[=T]0,'P!!#!UPDPR4"YT.G@U%E@F5"D&7"````````"0```!,!P``0)__
M_]P0````00Z@!42=5)Y300T=`R\$"MW>#!\`00L@````=`<``/BO__]4````
M`$$.$)T"G@%"#1U1WMT,'P````!$````F`<``"RP__\<`0```$$.0)T(G@="
M#1U!DP:4!4*5!)8#0I<"F`%;"M[=U]C5UM/4#!\`00MBWMW7V-76T]0,'P``
M```T````X`<```2Q__^X`0```$$.0)T(G@="#1U!DP:4!4*7`D*5!)8#`E\*
MWMW7U=;3U`P?`$$+````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````&%$```````"@4````````````````````0`````````!````````
M``$`````````<@(````````!`````````'P"`````````0````````"X`@``
M``````$`````````W@(````````/`````````'<$````````&0````````!8
MK0$``````!L`````````"``````````:`````````&"M`0``````'```````
M```(``````````0`````````2`(````````%`````````#@/````````!@``
M``````!X!0````````H`````````OP0````````+`````````!@`````````
M%0````````````````````,`````````Z*\!```````"```````````&````
M````%``````````'`````````!<`````````^!8````````'`````````/@3
M````````"````````````P````````D`````````&`````````#[__]O````
M``````@`````^?__;P`````6````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````<*T!``````!HK0$`````````````````````````
M``!8K0$``````````````````````````````````````$"S`0``````````
M``````!@K0$``````("R`0``````````````````````````````````````
MR+(!``````````````````"R`0``````V#D`````````````````````````
M````````````````'0`````````=`````````!T`````````'0`````````=
M`````````!T`````````'0`````````=`````````!T`````````'0``````
M```=`````````!T`````````'0`````````=`````````!T`````````'0``
M```````=`````````!T`````````'0`````````=`````````!T`````````
M'0`````````=`````````!T`````````'0`````````=`````````!T`````
M````'0`````````=`````````!T`````````'0`````````=`````````!T`
M````````'0`````````=`````````!T`````````'0`````````=````````
M`!T`````````'0`````````=`````````!T`````````'0`````````=````
M`````!T`````````'0`````````=`````````!T`````````'0`````````=
M`````````!T`````````'0`````````=`````````!T`````````'0``````
M```=`````````!T`````````'0`````````=`````````!T`````````'0``
M```````=`````````!T`````````'0```````,"R`0``````"+(!```````*
M4$%2+G!M"@``````````@%<```````"P4P```````````````````%4`````
M``!@5P```````&A7````````<%<```````!X5P``````````````````2%<`
M``````!05P``````````````````B%<```````!'0T,Z("A.971"4T0@;F(T
M(#(P,C`P.#$P*2`W+C4N,`!'0T,Z("AN8C0@,C`R,#`X,3`I(#<N-2XP`"1.
M971"4T0Z(&-R=#`N4RQV(#$N,B`R,#$X+S$Q+S(V(#$W.C,W.C0T(&IO97)G
M($5X<"`D`"1.971"4T0Z(&-R=#`M8V]M;6]N+F,L=B`Q+C(S(#(P,3@O,3(O
M,C@@,C`Z,3(Z,S4@8VAR:7-T;W,@17AP("0`)$YE=$)31#H@8W)T:2Y3+'8@
M,2XQ(#(P,30O,#@O,3`@,#4Z-#<Z,S8@;6%T="!%>'`@)``D3F5T0E-$.B!C
M<G1B96=I;BYC+'8@,2XQ-R`R,#$X+S$R+S(X(#$X.C$W.C$Q(&-H<FES=&]S
M($5X<"`D`"1.971"4T0Z(&-R=&5N9"Y3+'8@,2XQ(#(P,30O,#@O,3`@,#4Z
M-#<Z,S8@;6%T="!%>'`@)`#QSP(`````````````````"`````@````(````
M"````!L````!```````````J*BH@3F\@3&%B96P@4')O=FED960@*BHJ``#Q
MSP(`````````````````"`````@````(````"````!L````!```````````J
M*BH@3F\@3&%B96P@4')O=FED960@*BHJ```N<VAS=')T86(`+FEN=&5R<``N
M;F]T92YN971B<V0N:61E;G0`+FYO=&4N;F5T8G-D+G!A>``N:&%S:``N9'EN
M<WEM`"YD>6YS='(`+G)E;&$N9'EN`"YR96QA+G!L=``N=&5X=``N<F]D871A
M`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R
M<F%Y`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N8G-S`"YC
M;VUM96YT`"Y354Y77V-T9@``````````````````````````````````````
M``````````````````````````````````````````````````````L````!
M`````@```````````@`````````"````````%P````````````````````$`
M```````````````````3````!P````(`````````&`(````````8`@``````
M`!@````````````````````$````````````````````)@````<````"````
M`````#`"````````,`(````````4````````````````````!```````````
M`````````#<````%`````@````````!(`@```````$@"````````+`,`````
M```%``````````@`````````!``````````]````"P````(`````````>`4`
M``````!X!0```````,`)````````!@````,````(`````````!@`````````
M10````,````"`````````#@/````````.`\```````"_!```````````````
M`````0```````````````````$T````$`````@````````#X$P```````/@3
M``````````,````````%``````````@`````````&`````````!7````!```
M`$(`````````^!8```````#X%@`````````&````````!0```!,````(````
M`````!@`````````7`````$````&```````````=`````````!T````````@
M!```````````````````$``````````0`````````&$````!````!@``````
M```@(0```````"`A````````8#(```````````````````@`````````````
M``````!G`````0````(`````````@%,```````"`4P```````'A!````````
M```````````(````````````````````;P````$````"`````````/B4````
M````^)0````````$`0``````````````````!````````````````````'T`
M```!`````@``````````E@````````"6````````'`@`````````````````
M``@```````````````````"'````#@````,`````````6*T!``````!8K0``
M``````@````````````````````(``````````@`````````DP````\````#
M`````````&"M`0``````8*T````````(````````````````````"```````
M```(`````````)\````!`````P````````!HK0$``````&BM````````"```
M``````````````````@```````````````````"D````!@````,`````````
M<*T!``````!PK0```````.`!````````!@`````````(`````````!``````
M````K0````$````#`````````%"O`0``````4*\```````"8````````````
M````````"``````````(`````````+(````!`````P````````#HKP$`````
M`.BO````````&`(```````````````````@`````````"`````````"[````
M`0````,``````````+(!````````L@```````(@````````````````````(
M````````````````````P0````@````#`````````,"R`0``````B+(`````
M``"(````````````````````0````````````````````,8````!````,```
M`````````````````(BR````````.P````````````````````$`````````
M`0`````````?`````0````````````````````````##L@```````"$!````
M```````````````!````````````````````SP````$`````````````````
M````````Y+,```````"/````````````````````!```````````````````
M``$````#`````````````````````````'.T````````V0``````````````
4``````$`````````````````````
